@@ -9,7 +9,7 @@ from redis_cache.cache import RedisCache
 from cascache.exceptions import NoneValueError
 
 
-MAX_RETRIES = settings.get('CAS_CACHE_MAX_RETRIES', 10)
+MAX_RETRIES = getattr(settings, 'CAS_CACHE_MAX_RETRIES', 10)
 
 
 class CASMixin(object):
